<?php

if (!defined('_PS_VERSION_'))
    exit;

class VACimb extends PaymentModule {

  private $_html = '';
    private $_postErrors = array();
    public $merchant_code;
    public $api_key;

    public function __construct() {
        $this->name = 'vacimb';
        $this->tab = 'payments_gateways';
        $this->version = '1.1.0';
        $this->author = 'Kharisma Catur Mandala';
        $this->controllers = array('payment', 'validation');

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $config = Configuration::getMultiple(array('DUITKU_VACIMB_MERCHANTCODE', 'DUITKU_VACIMB_APIKEY'));
        if (!empty($config['DUITKU_VACIMB_MERCHANTCODE']))
            $this->merchant_code = $config['DUITKU_VACIMB_MERCHANTCODE'];
        if (!empty($config['DUITKU_VACIMB_APIKEY']))
            $this->api_key = $config['DUITKU_VACIMB_APIKEY'];
		if (!empty($config['DUITKU_VACIMB_URL']))
            $this->api_key = $config['DUITKU_VACIMB_URL'];

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('VA CIMB');
        $this->description = $this->l('Accept payments for your products via Duitku.');
        $this->confirmUninstall = $this->l('Are you sure about removing these details?');
        if (!isset($this->merchant_code) || !isset($this->api_key))
            $this->warning = $this->l('MERCHANT_CODE and API_KEY details must be configured before using this module.');
        if (!count(Currency::checkPaymentCurrencies($this->id)))
            $this->warning = $this->l('No currency has been set for this module.');
    }

    public function install() {
        if (!parent::install() || !$this->registerHook('payment') || !$this->registerHook('paymentReturn'))
            return false;
        return true;
    }

    public function uninstall() {
        if (!Configuration::deleteByName('DUITKU_VACIMB_MERCHANTCODE') || !Configuration::deleteByName('DUITKU_VACIMB_URL') || !Configuration::deleteByName('DUITKU_VACIMB_APIKEY') || 
		!Configuration::deleteByName('DUITKU_VACIMB_SUCCESS_STATUS') || !Configuration::deleteByName('DUITKU_VACIMB_PENDING_STATUS') || !Configuration::deleteByName('DUITKU_VACIMB_FAILURE_STATUS') || !parent::uninstall())
            return false;
        return true;
    }

    private function _postValidation() {
        if (Tools::isSubmit('btnSubmit')) {
            if (!Tools::getValue('DUITKU_VACIMB_MERCHANTCODE'))
                $this->_postErrors[] = $this->l('Merchant code is required.');
            elseif (!Tools::getValue('DUITKU_VACIMB_APIKEY'))
                $this->_postErrors[] = $this->l('Api key is required.');
			elseif (!Tools::getValue('DUITKU_VACIMB_URL'))
                $this->_postErrors[] = $this->l('Url is required.');
        }
    }

    private function _postProcess() {
        if (Tools::isSubmit('btnSubmit')) {
            Configuration::updateValue('DUITKU_VACIMB_MERCHANTCODE', Tools::getValue('DUITKU_VACIMB_MERCHANTCODE'));
            Configuration::updateValue('DUITKU_VACIMB_APIKEY', Tools::getValue('DUITKU_VACIMB_APIKEY'));
			Configuration::updateValue('DUITKU_VACIMB_URL', Tools::getValue('DUITKU_VACIMB_URL'));
			Configuration::updateValue('DUITKU_VACIMB_SUCCESS_STATUS', Tools::getValue('DUITKU_VACIMB_SUCCESS_STATUS'));
			Configuration::updateValue('DUITKU_VACIMB_PENDING_STATUS', Tools::getValue('DUITKU_VACIMB_PENDING_STATUS'));
			Configuration::updateValue('DUITKU_VACIMB_FAILURE_STATUS', Tools::getValue('DUITKU_VACIMB_FAILURE_STATUS'));
        }
        $this->_html .= $this->displayConfirmation($this->l('Settings updated'));
    }

    private function _displayVACimb() {
        return $this->display(__FILE__, 'infos.tpl');
    }

    public function getContent() {
        if (Tools::isSubmit('btnSubmit')) {
            $this->_postValidation();
            if (!count($this->_postErrors))
                $this->_postProcess();
            else
                foreach ($this->_postErrors as $err)
                    $this->_html .= $this->displayError($err);
        } else {
            $this->_html .= '<br />';
        }

        $this->_html .= $this->_displayVACimb();
        $this->_html .= $this->renderForm();

        return $this->_html;
    }

    public function hookPayment($params) {
        if (!$this->active)
            return;
        if (!$this->checkCurrency($params['cart']))
            return;

        $this->context->controller->addCSS($this->_path . 'vacimb.css', 'all');
        $this->smarty->assign(array(
            'this_path' => $this->_path,
            'this_path_bw' => $this->_path,
            'this_path_ssl' => Tools::getShopDomainSsl(true, true) . __PS_BASE_URI__ . 'modules/' . $this->name . '/'
        ));
        return $this->display(__FILE__, 'payment.tpl');
    }

    public function hookPaymentReturn($params) {
        if (!$this->active)
            return;

        return $this->display(__FILE__, 'payment_return.tpl');
    }

    public function checkCurrency($cart) {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module))
            foreach ($currencies_module as $currency_module)
                if ($currency_order->id == $currency_module['id_currency'])
                    return true;
        return false;
    }

    public function renderForm() {		
		$order_states = array();
		foreach (OrderState::getOrderStates($this->context->language->id) as $state) {
			array_push($order_states, array(
				'id_option' => $state['id_order_state'],
				'name' => $state['name']
				)
			);
		}
		
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('VA CIMB API DETAILS'),
                    'icon' => 'icon-envelope'
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('MERCHANT CODE'),
                        'name' => 'DUITKU_VACIMB_MERCHANTCODE',
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('API KEY'),
                        'name' => 'DUITKU_VACIMB_APIKEY',
                    ),
					array(
                        'type' => 'text',
                        'label' => $this->l('URL'),
                        'name' => 'DUITKU_VACIMB_URL',
                    ),
					array(
						'type' => 'select',
						'label' => 'Map payment SUCCESS status to:',
						'name' => 'DUITKU_VACIMB_SUCCESS_STATUS',
						'required' => true,	
						'options' => array(
							'query' => $order_states,
							'id' => 'id_option',
							'name' => 'name'
							),
						//'class' => ''
						),
					array(
						'type' => 'select',
						'label' => 'Map payment PENDING status to:',
						'name' => 'DUITKU_VACIMB_PENDING_STATUS',
						'required' => true,	
						'options' => array(
							'query' => $order_states,
							'id' => 'id_option',
							'name' => 'name'
							),
						//'class' => ''
						),
					array(
						'type' => 'select',
						'label' => 'Map payment FAILURE status to:',
						'name' => 'DUITKU_VACIMB_FAILURE_STATUS',
						'required' => true,
						'options' => array(
							'query' => $order_states,
							'id' => 'id_option',
							'name' => 'name'
							),
						//'class' => ''
						),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $lang = new Language((int) Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $this->fields_form = array();
        $helper->id = (int) Tools::getValue('id_carrier');
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'btnSubmit';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues() {
        return array(
            'DUITKU_VACIMB_MERCHANTCODE' => Tools::getValue('DUITKU_VACIMB_MERCHANTCODE', Configuration::get('DUITKU_VACIMB_MERCHANTCODE')),
            'DUITKU_VACIMB_APIKEY' => Tools::getValue('DUITKU_VACIMB_APIKEY', Configuration::get('DUITKU_VACIMB_APIKEY')),
            'DUITKU_VACIMB_URL' => Tools::getValue('DUITKU_VACIMB_URL', Configuration::get('DUITKU_VACIMB_URL')),
			'DUITKU_VACIMB_SUCCESS_STATUS' => Tools::getValue('DUITKU_VACIMB_SUCCESS_STATUS', Configuration::get('DUITKU_VACIMB_SUCCESS_STATUS')),
			'DUITKU_VACIMB_PENDING_STATUS' => Tools::getValue('DUITKU_VACIMB_PENDING_STATUS', Configuration::get('DUITKU_VACIMB_PENDING_STATUS')),
			'DUITKU_VACIMB_FAILURE_STATUS' => Tools::getValue('DUITKU_VACIMB_FAILURE_STATUS', Configuration::get('DUITKU_VACIMB_FAILURE_STATUS')),
        );
    }
}
